@@ -39,6 +39,8 @@ class Namespace:
     builder_version: str
     generate_docs: bool
     list_services: bool
+    partial_overload: bool
+    skip_published: bool
 
 
 def parse_args(args: Sequence[str]) -> Namespace:
@@ -58,7 +60,7 @@ def parse_args(args: Sequence[str]) -> Namespace:
     parser.add_argument(
         "-b",
         "--build-version",
-        help="Set custom output version, otherwise boto3 version is used.",
+        help="Set custom output version, otherwise smart versioning is used.",
     )
     parser.add_argument("-V", "--version", action="version", version=version)
     parser.add_argument(
@@ -69,6 +71,9 @@ def parse_args(args: Sequence[str]) -> Namespace:
     parser.add_argument(
         "--skip-services", action="store_true", help="Whether to skip service modules"
     )
+    parser.add_argument(
+        "--skip-published", action="store_true", help="Skip packages that are already on PyPI"
+    )
     parser.add_argument("--docs", action="store_true", help="Generate docs for modules")
     parser.add_argument(
         "--panic",
@@ -91,6 +96,11 @@ def parse_args(args: Sequence[str]) -> Namespace:
         ),
         default=["all"],
     )
+    parser.add_argument(
+        "--partial-overload",
+        action="store_true",
+        help="Build boto3-stubs client/service overload only for selected services",
+    )
     parser.add_argument(
         "--installed",
         action="store_true",
@@ -114,4 +124,6 @@ def parse_args(args: Sequence[str]) -> Namespace:
         builder_version=result.builder_version,
         generate_docs=result.docs,
         list_services=result.list_services,
+        partial_overload=result.partial_overload,
+        skip_published=result.skip_published,
     )
