@@ -17,6 +17,8 @@ class ServiceName:
     Description for boto3 service.
     """
 
+    ALL = "all"
+    UPDATED = "updated"
     LATEST = "latest"
     ESSENTIAL = (
         "ec2",
@@ -210,25 +212,6 @@ class ServiceNameCatalog:
         lambda_.name: lambda_,
     }
 
-    @classmethod
-    def find(cls, name: str) -> ServiceName:
-        """
-        Get `ServiceName` by import name.
-
-        Arguments:
-            name -- Service import name.
-
-        Returns:
-            ServiceName.
-
-        Raises:
-            ValueError -- If ServiceName not found.
-        """
-        try:
-            return cls.ITEMS[name]
-        except KeyError as exc:
-            raise ValueError(f"Unknown service {name}") from exc
-
     @classmethod
     def add(cls, name: str, class_name: str) -> ServiceName:
         """
