@@ -3,21 +3,6 @@ Predefined FakeAnnotation instances.
 """
 from datetime import datetime
 from decimal import Decimal
-from typing import (
-    IO,
-    Any,
-    Callable,
-    Dict,
-    Generator,
-    Iterator,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Set,
-)
-from typing import Type as TypingType
-from typing import Union, overload
 
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 from mypy_boto3_builder.type_annotations.remove_argument import RemoveArgument
@@ -32,35 +17,35 @@ class Type:
     Predefined FakeAnnotation instances.
     """
 
-    Union = TypeAnnotation(Union)
-    Any = TypeAnnotation(Any)
-    Dict = TypeAnnotation(Dict)
-    Mapping = TypeAnnotation(Mapping)
-    List = TypeAnnotation(List)
-    Sequence = TypeAnnotation(Sequence)
-    Optional = TypeAnnotation(Optional)  # type: ignore
-    Callable = TypeAnnotation(Callable)
-    IO = TypeAnnotation(IO)
-    overload = TypeAnnotation(overload)
+    Union = TypeAnnotation("Union")
+    Any = TypeAnnotation("Any")
+    Dict = TypeAnnotation("Dict")
+    Mapping = TypeAnnotation("Mapping")
+    List = TypeAnnotation("List")
+    Sequence = TypeAnnotation("Sequence")
+    Optional = TypeAnnotation("Optional")
+    Callable = TypeAnnotation("Callable")
+    IO = TypeAnnotation("IO")
+    overload = TypeAnnotation("overload")
     none = TypeConstant(None)
     str = TypeClass(str)
-    Set = TypeAnnotation(Set)
+    Set = TypeAnnotation("Set")
     bool = TypeClass(bool)
     bytes = TypeClass(bytes)
     bytearray = TypeClass(bytearray)
     int = TypeClass(int)
     float = TypeClass(float)
     Ellipsis = TypeConstant(...)
-    Generator = TypeAnnotation(Generator)
     Decimal = TypeClass(Decimal)
-    Type = TypeAnnotation(TypingType)
-    Iterator = TypeAnnotation(Iterator)
+    Type = TypeAnnotation("Type")
+    Iterator = TypeAnnotation("Iterator")
     datetime = TypeClass(datetime)
 
     ListAny = TypeSubscript(List, [Any])
     SequenceAny = TypeSubscript(Sequence, [Any])
     MappingStrAny = TypeSubscript(Mapping, [str, Any])
     DictStrAny = TypeSubscript(Dict, [str, Any])
+    DictStrStr = TypeSubscript(Dict, [str, str])
     IOBytes = TypeSubscript(IO, [bytes])
     RemoveArgument = RemoveArgument()
 
@@ -72,7 +57,7 @@ class Type:
         if (
             isinstance(wrapped, TypeSubscript)
             and isinstance(wrapped.parent, TypeAnnotation)
-            and wrapped.parent.wrapped_type is Union
+            and wrapped.parent.is_union()
         ):
             result = wrapped.copy()
             result.add_child(cls.none)
