@@ -1,8 +1,8 @@
 """
 Path that represents it as relative to workdir.
 """
+from collections.abc import Iterable, Iterator
 from pathlib import Path
-from typing import Iterable, Iterator
 
 
 class NicePath(type(Path())):  # type: ignore
